@@ -794,7 +794,7 @@ class DcsConnection(ServerConnection):
         if self._logdataTimeStamp != None:
             difference = datetime.now() - self._logdataTimeStamp
             if(difference.total_seconds() < LOGDATABLOCKTIME): 
-                logging.warning(str(id(self)) + " cannot get logdata. Minimum waiting time not reached. " + str(difference.total_seconds()))
+                logging.warning(str(id(self)) + " cannot get logdata. Minimum waiting time (" + str(LOGDATABLOCKTIME) +") not reached. " + str(difference.total_seconds()))
                 raise Exception("Logdata not ready.")
 
         t = datetime.now()
