@@ -46,11 +46,11 @@ class DeviceDcElwa(ModbusRtuDevice):
         self._channels["dc_breaker_state"] = ChannelConfig([1002], "NUMBER", 0, datasettype="sum")
         self._channels["dc_relay_state"] = ChannelConfig([1003], "NUMBER", 0, datasettype="sum")
         self._channels["ac_relay_state"] = ChannelConfig([1004], "NUMBER", 0, datasettype="sum")
-        self._channels["temp1"] = ChannelConfig([1005], "NUMBER", 0, datasettype="avg")     #ELWA Temperatur sensor
-        self._channels["temp_day_min"] = ChannelConfig([1006], "NUMBER", 0, datasettype="avg")
-        self._channels["temp_day_max"] = ChannelConfig([1007], "NUMBER", 0, datasettype="avg")
-        self._channels["dc_temp_target"] = ChannelConfig([1008], "NUMBER", 0, "rw", datasettype="avg")
-        self._channels["ac_temp_target"] = ChannelConfig([1009], "NUMBER", 0, "rw", datasettype="avg")
+        self._channels["temp1"] = ChannelConfig([1005], "NUMBER", 0.1, datasettype="avg")     #ELWA Temperatur sensor
+        self._channels["temp_day_min"] = ChannelConfig([1006], "NUMBER", 0.1, datasettype="avg")
+        self._channels["temp_day_max"] = ChannelConfig([1007], "NUMBER", 0.1, datasettype="avg")
+        self._channels["dc_temp_target"] = ChannelConfig([1008], "NUMBER", 0.1, "rw", datasettype="avg")
+        self._channels["ac_temp_target"] = ChannelConfig([1009], "NUMBER", 0.1, "rw", datasettype="avg")
         self._channels["tempchip"] = ChannelConfig([1010], "NUMBER", 0, datasettype="avg")
         self._channels["iso_voltage"] = ChannelConfig([1011], "NUMBER", 0, datasettype="avg")
         self._channels["dc_voltage"] = ChannelConfig([1012], "NUMBER", 0, datasettype="avg")
@@ -63,7 +63,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         self._channels["minutes_since_dusk"] = ChannelConfig([1019], "NUMBER", 0, datasettype="avg")
         self._channels["ac_boost_mode"] = ChannelConfig([1020], "NUMBER", 0, "rw", datasettype="avg")
         self._channels["temp2"] = ChannelConfig([1021], "NUMBER", 0.1, datasettype="avg")     #IR-Interface temperature sensor
-        self._channels["boost_temp_target"] = ChannelConfig([1022], "NUMBER", 0, "rw", datasettype="avg")     #ELWA Modbus Interface boost temperature
+        self._channels["boost_temp_target"] = ChannelConfig([1022], "NUMBER", 0.1, "rw", datasettype="avg")     #ELWA Modbus Interface boost temperature
         self._channels["ww2offset_calibration"] = ChannelConfig([1023], "NUMBER", 0, "rw", datasettype="avg")     #Temp sensor offset calibration
 
         self._setup["device"] = SetupMapping(defaultvalue=self.getdevicetype())
@@ -73,30 +73,8 @@ class DeviceDcElwa(ModbusRtuDevice):
         self._setup["ww2target"] = SetupMapping("boost_temp_target")
         self._setup["ww2offset"] = SetupMapping("ww2offset_calibration", forced=True, defaultvalue=1514)
 
-    #     datasets["day_counter"] = self._createDataset(1000, "avg")
-    #     datasets["operation_mode"] = self._createDataset(1001, "avg")
-    #     datasets["dc_breaker_state"] = self._createDataset(1002, "avg")
-    #     datasets["dc_relay_state"] = self._createDataset(1003, "sum")
-    #     datasets["ac_relay_state"] = self._createDataset(1004, "sum")
-    #     datasets["temp1"] = self._createDataset(1005, "avg")
-    #     datasets["temp_day_min"] = self._createDataset(1006, "avg")
-    #     datasets["temp_day_max"] = self._createDataset(1007, "avg")
-    #     datasets["dc_temp_target"] = self._createDataset(1008, "avg")
-    #     datasets["ac_temp_target"] = self._createDataset(1009, "avg")
-    #     datasets["tempchip"] = self._createDataset(1010, "avg")
-    #     datasets["iso_voltage"] = self._createDataset(1011, "avg")
-    #     datasets["dc_voltage"] = self._createDataset(1012, "avg")
-    #     datasets["dc_current"] = self._createDataset(1013, "avg")
-    #     datasets["dc_power"] = self._createDataset(1014, "sum")
-    #     datasets["dc_day_wh"] = self._createDataset(1015, "avg")
-    #     datasets["dc_total_kwh"] = self._createDataset(1016, "avg")
-    #     datasets["ac_day_wh"] = self._createDataset(1017, "avg")
-    #     datasets["minutes_from_noon"] = self._createDataset(1018, "avg")
-    #     datasets["minutes_since_dusk"] = self._createDataset(1019, "avg")
-    #     datasets["ac_boost_mode"] = self._createDataset(1020, "avg")
-    #     datasets["temp2"] = self._createDataset(1021, "avg")
-    #     datasets["boost_temp_target"] = self._createDataset(1022, "avg")
-    #     datasets["ww2offset_calibration"] = self._createDataset(1023, "avg")
+    def getdevicetype(self):
+        return "ELWA"
 
     def getdata(self):
 
@@ -142,15 +120,15 @@ class DeviceDcElwa(ModbusRtuDevice):
             "dc_breaker": self.getchannelvalue("dc_breaker_state", True),
             "dc_relay": self.getchannelvalue("dc_relay_state", True),
             "ac_relay": acRelayState,
-            "temp1": self.getchannelvalue("temp1", True),
-            "temp_day_min": self.getchannelvalue("temp_day_min", True),
-            "temp_day_max": self.getchannelvalue("temp_day_max", True),
-            "ww1target": self.getchannelvalue("dc_temp_target", True),
-            "ac_temp_target": self.getchannelvalue("ac_temp_target", True),
+            "temp1": self.getchannelvalue("temp1", True, 10),
+            "temp_day_min": self.getchannelvalue("temp_day_min", True, 10),
+            "temp_day_max": self.getchannelvalue("temp_day_max", True, 10),
+            "ww1target": self.getchannelvalue("dc_temp_target", True, 10),
+            "ac_temp_target": self.getchannelvalue("ac_temp_target", True, 10),
             "tempchip": self.getchannelvalue("tempchip", True),
             "iso_voltage": self.getchannelvalue("iso_voltage", True),
-            "dc_voltage": self.getchannelvalue("dc_voltage", True),
-            "dc_current": self.getchannelvalue("dc_current", True),
+            "dc_voltage": self.getchannelvalue("dc_voltage", True, 10),
+            "dc_current": self.getchannelvalue("dc_current", True, 10),
             "power_elwa": power,
             "boostpower_elwa": boostpower,
             "dc_day_wh": self.getchannelvalue("dc_day_wh", True),
@@ -161,7 +139,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             "ac_boost_mode": self.getchannelvalue("ac_boost_mode", True),
             "m1sum": dcPower,
             "m0sum": meter,
-            "temp2": self.getchannelvalue("temp2", True),
+            "temp2": self.getchannelvalue("temp2", True, 10),
             "ww2target": self.getchannelvalue("boost_temp_target", True),
             "ww2offset": self.getchannelvalue("ww2offset_calibration", True),
             "modbuserrorrate":  errorrate,
@@ -170,9 +148,9 @@ class DeviceDcElwa(ModbusRtuDevice):
         }       
         return data
 
-    def getchannelvalue(self, datasetname, safemode):
+    def getchannelvalue(self, datasetname, safemode=False, scale=None):
         if self._irerror == False or datasetname in ("temp2"):
-            return super().getchannelvalue(datasetname, safemode)
+            return super().getchannelvalue(datasetname, safemode, scale)
         else:
             return None
 
@@ -209,11 +187,11 @@ class DeviceDcElwa(ModbusRtuDevice):
 			"dc_breaker": self.getlogvalue("dc_breaker_state", "int"),
 			"dc_relay": self.getlogvalue("dc_relay_state", "int"),
 			"ac_relay": self.getlogvalue("ac_relay_state", "int"),
-			"temp": self.getlogvalue("temp1", "int"),
-			"temp_day_min": self.getlogvalue("temp_day_min", "int"),
-			"temp_day_max": self.getlogvalue("temp_day_max", "int"),
-			"dc_temp_target": self.getlogvalue("dc_temp_target", "int"),
-			"ac_temp_target": self.getlogvalue("ac_temp_target", "int"),
+			"temp": self.getlogvalue("temp1", "int", 10),
+			"temp_day_min": self.getlogvalue("temp_day_min", "int", 10),
+			"temp_day_max": self.getlogvalue("temp_day_max", "int", 10),
+			"dc_temp_target": self.getlogvalue("dc_temp_target", "int", 10),
+			"ac_temp_target": self.getlogvalue("ac_temp_target", "int", 10),
 			"temp_internal": self.getlogvalue("tempchip", "int"),
 			"iso_voltage": self.getlogvalue("iso_voltage", "int"),
 			"dc_voltage": self.getlogvalue("dc_voltage", "int"),
@@ -225,7 +203,7 @@ class DeviceDcElwa(ModbusRtuDevice):
 			"minutes_from_noon": self.getlogvalue("minutes_from_noon", "int"),
 			"minutes_since_dusk": self.getlogvalue("minutes_since_dusk", "int"),
 			"ac_boost_mode": self.getlogvalue("ac_boost_mode", "int"),
-			"temp2": self.getlogvalue("temp2", "int"),
+			"temp2": self.getlogvalue("temp2", "int", 10),
 			"ww2target": self.getlogvalue("boost_temp_target", "int"),
 			"ww2offset": self.getlogvalue("ww2offset_calibration", "int"),
         }
@@ -236,8 +214,8 @@ class DeviceDcElwa(ModbusRtuDevice):
             "i_boostpower": boostpower,
             "i_m1sum": pvprod,
             "i_metercons": metercons,
-            "i_temp1": self.getlogvalue("temp1", "int"),
-            "i_temp2": self.getlogvalue("temp2", "int"),
+            "i_temp1": self.getlogvalue("temp1", "int", 10),
+            "i_temp2": self.getlogvalue("temp2", "int", 10),
             "s_json" : json.dumps(sLog)
         }
 
@@ -245,9 +223,9 @@ class DeviceDcElwa(ModbusRtuDevice):
         # self._logdata.clear()  #todo sicher?
         return logData
 
-    def getlogvalue(self, datasetname, casttype=None):
+    def getlogvalue(self, datasetname, casttype=None, scale=None):
         if self._irerror == False or datasetname in ("temp2"):
-            return super().getlogvalue(datasetname, casttype)
+            return super().getlogvalue(datasetname, casttype, scale)
         else:
             return None
 
@@ -491,7 +469,7 @@ if __name__ == "__main__":
         print(color('ERROR: getting getLogData.', fore='red', style='bright'))
 
     key = "ww2target"
-    targetValue = 534
+    targetValue = 55
     try:
         device.setsetupvalue(key, targetValue)
         print(color('SUCCESS: sending setup value to device.', fore='green', style='bright'))
@@ -537,10 +515,12 @@ if __name__ == "__main__":
     device.start()
 
     try:
+        time.sleep(10)
         while True:
             print(color('[DeviceDcElwa] test active. Press CTRL+C to stop', fore='blue', style='bright'))
-            # print(device.getinfo())
-            # device.showcommunicationerrors()
+            print(device)
+            print(device.getinfo())
+            device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
             time.sleep(10)
     except KeyboardInterrupt as e:
