@@ -15,7 +15,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 from mypvdevices.ServerConnection import ServerConnection
 from mypvdevices.Dataprocessor import Dataprocessor
 
-BUILDNR = "1.2112.12"
+BUILDNR = "1.2112.13"
 
 JOINTIMEOUTSECONDS = 5
 MONITORSLEEPTIMESECONDS = 10
@@ -97,13 +97,14 @@ class GeneralDevice:
     def start(self):
         self._running = True
         logging.debug(str(self._name) + " starting...")
-        self._monitorthread = threading.Thread(target=self._run, name="Monitor " + str(self._name))
-        self._monitorthread.start()
         self._busCommunicationThread = threading.Thread(target=self._runbuscommunication, name="BusCommunication " + str(self._name))
         self._busCommunicationThread.start()
         time.sleep(10)
         for connection in self._serverconnections:
             connection.connect()
+        time.sleep(5)
+        self._monitorthread = threading.Thread(target=self._run, name="Monitor " + str(self._name))
+        self._monitorthread.start()
         logging.debug(str(self._name) + " started.")
     
     def stop(self):
@@ -615,7 +616,7 @@ class GeneralDevice:
         if self._datasetdefinitions != None:
             for dataset in self._datasetdefinitions:
                 try:
-                    output += "\n" + dataset + ": Live: " + str(self.getchannelvalue(dataset)) + ", Log: " + str(self.getlogvalue(dataset))
+                    output += "\n" + str(dataset).rjust(30) + ": Live: " + str(self.getchannelvalue(dataset)).ljust(8) + " Log: " + str(self.getlogvalue(dataset)).ljust(8)
                 except Exception as e:
                     logging.debug(str(self._name) + " Error getting deviceInfo. " + str(e))
 
@@ -735,7 +736,7 @@ class GeneralDevice:
         if config.channeltype == None:
             registerValues = [value]
         elif config.channeltype == "NUMBER":
-            registerValues = [value]
+            registerValues = [int(value)]
         elif config.channeltype == "UINT16":
             registerValues = Dataprocessor.instance().encode_16bit_uint(value)
         elif config.channeltype == "UINT32":
@@ -746,7 +747,10 @@ class GeneralDevice:
         
         if len(config.registers) > 0:
             startregister = config.registers[0]
-            self.writeregisters(startregister, registerValues)
+            if len(registerValues) > 1:
+                self.writeregisters(startregister, registerValues)
+            else:
+                self.writeregister(startregister, registerValues[0])
         else:
             raise Exception("Invalid config: " + str(config))
 
