@@ -76,12 +76,15 @@ class ModbusConnection:     #Singleton
     def getModbusErrorRate(self, node):
         try:
             self.__connectionErrorCounter__[node]
+            self.__connectionCounter__[node]
         except:
             return 0
 
         try:
+            if self.__connectionCounter__[node] == 0:
+                return 0
             return round(self.__connectionErrorCounter__[node] / self.__connectionCounter__[node], 2)
-        except:
+        except Exception as e:
             logging.warning("[ModbusConnection] Node " + str(node) + ": Cannot calculate error rate.")
             return None
 
