@@ -145,6 +145,7 @@ class SerialDevice(GeneralDevice):
             raise Exception("Serial communication failed.")
         except Exception as e:
             self._increaseBusErrorCounter()
+            self._commport.close()
             raise Exception("Register " + str(registertype) + ":" + str(registerId) + " cannot be read. " + str(e))
 
     def _readregisters(self, startregisteraddress, registerstoread, registertype="serial"):
@@ -166,6 +167,7 @@ class SerialDevice(GeneralDevice):
             raise Exception("Serial communication failed.")
         except Exception as e:
             self._increaseBusErrorCounter()
+            self._commport.close()
             raise Exception("Registers " + str(registertype) + ":" + str(startregisteraddress) + ":" + str(registerstoread) + " cannot be read. " + str(e))
 
     def _writeserialdata(self, data):
@@ -481,7 +483,7 @@ class SerialDevice(GeneralDevice):
 #     try:
 #         while True:
 #             print(color('[SerialDevice] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
-#             device.showinfo()
+#             print(device.getinfo())
 #             device.showcommunicationerrors()
 #             device.showcommunicationerrorsrate()
 #             time.sleep(10)
